<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Blogi
 */

if ( ! function_exists( 'the_posts_navigation' ) ) :
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 *
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function the_posts_navigation() {
		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}
		?>
	<nav class="navigation posts-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'blogi' ); ?></h2>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( esc_html__( 'Older posts', 'blogi' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( esc_html__( 'Newer posts', 'blogi' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
		<?php
	}
endif;

if ( ! function_exists( 'the_post_navigation' ) ) :
	/**
	 * Display navigation to next/previous post when applicable.
	 *
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function the_post_navigation() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous ) {
			return;
		}
		?>
	<nav class="navigation post-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'blogi' ); ?></h2>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', '%title' );
				next_post_link( '<div class="nav-next">%link</div>', '%title' );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
		<?php
	}
endif;

if ( ! function_exists( 'blogi_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function blogi_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated hidden" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

		$byline = '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>';

		$categories = get_the_category_list( esc_html__( ', ', 'blogi' ) );

		echo sprintf(
			'<span class="posted-on"><i class="fa fa-calendar"></i> %1$s</span> <span class="byline"><i class="fa fa-user"></i> %2$s</span><span class="posted-in"><i class="fa fa-folder-open"></i> %3$s</span>',
			wp_kses(
				$posted_on,
				array(
					'a'    => array(
						'href' => array(),
						'rel'  => array(),
					),
					'time' => array(
						'class'    => array(),
						'datetime' => array(),
					),
				)
			),
			wp_kses(
				$byline,
				array(
					'span' => array(
						'class' => array(),
					),
					'a'    => array(
						'class' => array(),
						'href'  => array(),
					),
				)
			),
			wp_kses(
				$categories,
				array(
					'a' => array(
						'href' => array(),
						'rel'  => array(),
					),
				)
			)
		);

	}
endif;

if ( ! function_exists( 'blogi_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function blogi_entry_footer() {
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			echo '<i class="fa fa-comments"></i> ';
			comments_popup_link( esc_html__( 'Leave a comment', 'blogi' ), esc_html__( '1 Comment', 'blogi' ), esc_html__( '% Comments', 'blogi' ) );
			echo '</span>';
		}

		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'blogi' ) );
			if ( $tags_list ) {
				printf(
					/* translators: Post Tag list */
					'<span class="tags-links">' . wp_kses( __( '<i class="fa fa-tags"></i> %1$s', 'blogi' ), array( 'i' => array( 'class' => array() ) ) ) . '</span>',
					wp_kses(
						$tags_list,
						array(
							'a' => array(
								'href' => array(),
								'rel'  => array(),
							),
						)
					)
				);
			}
		}

		edit_post_link( esc_html__( 'Edit', 'blogi' ), '<span class="edit-link"><i class="fa fa-pencil"></i> ', '</span>' );
	}
endif;
